package com.fs.store.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsLevelMapper;
import com.fs.store.domain.FsLevel;
import com.fs.store.service.IFsLevelService;

/**
 * 设置用户等级Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsLevelServiceImpl implements IFsLevelService 
{
    @Autowired
    private FsLevelMapper fsLevelMapper;

    /**
     * 查询设置用户等级
     * 
     * @param id 设置用户等级ID
     * @return 设置用户等级
     */
    @Override
    public FsLevel selectFsLevelById(Long id)
    {
        return fsLevelMapper.selectFsLevelById(id);
    }

    /**
     * 查询设置用户等级列表
     * 
     * @param fsLevel 设置用户等级
     * @return 设置用户等级
     */
    @Override
    public List<FsLevel> selectFsLevelList(FsLevel fsLevel)
    {
        return fsLevelMapper.selectFsLevelList(fsLevel);
    }

    /**
     * 新增设置用户等级
     * 
     * @param fsLevel 设置用户等级
     * @return 结果
     */
    @Override
    public int insertFsLevel(FsLevel fsLevel)
    {
        fsLevel.setCreateTime(DateUtils.getNowDate());
        return fsLevelMapper.insertFsLevel(fsLevel);
    }

    /**
     * 修改设置用户等级
     * 
     * @param fsLevel 设置用户等级
     * @return 结果
     */
    @Override
    public int updateFsLevel(FsLevel fsLevel)
    {
        fsLevel.setUpdateTime(DateUtils.getNowDate());
        return fsLevelMapper.updateFsLevel(fsLevel);
    }

    /**
     * 批量删除设置用户等级
     * 
     * @param ids 需要删除的设置用户等级ID
     * @return 结果
     */
    @Override
    public int deleteFsLevelByIds(Long[] ids)
    {
        return fsLevelMapper.deleteFsLevelByIds(ids);
    }

    /**
     * 删除设置用户等级信息
     * 
     * @param id 设置用户等级ID
     * @return 结果
     */
    @Override
    public int deleteFsLevelById(Long id)
    {
        return fsLevelMapper.deleteFsLevelById(id);
    }
}
